@@ -93,6 +93,13 @@ InitInput (int argc, char **argv)
   KdInitInput();
 }
 
+#ifdef DDXBEFORERESET
+void
+ddxBeforeReset (void)
+{
+}
+#endif
+
 void
 ddxUseMsg (void)
 {
