@@ -23,7 +23,6 @@
 #ifdef HAVE_CONFIG_H
 #include <kdrive-config.h>
 #endif
-#define NEED_EVENTS
 #include <X11/X.h>
 #include <X11/Xproto.h>
 #include <X11/Xpoll.h>
@@ -73,19 +72,19 @@ BusInit (KdPointerInfo *pi)
     {
         for (i = 0; i < NUM_BUS_NAMES; i++)
         {
-            if ((fd = open (BusNames[i], 0)) > 0)
+            if ((fd = open (BusNames[i], 0)) >= 0)
             {
                 close(fd);
                 if (pi->path)
                     xfree(pi->path);
-                pi->path = KdSaveString(BusNames[i]);
+                pi->path = strdup(BusNames[i]);
                 return Success;
             }
         }
     }
     else
     {
-        if ((fd = open(pi->path, 0)) > 0)
+        if ((fd = open(pi->path, 0)) >= 0)
         {
             close(fd);
             return Success;
@@ -100,7 +99,7 @@ BusEnable (KdPointerInfo *pi)
 {
     int fd = open(pi->path, 0);
 
-    if (fd > 0)
+    if (fd >= 0)
     {
         KdRegisterFd(fd, BusRead, pi);
         pi->driverPrivate = (void *)fd;
