@@ -35,7 +35,6 @@
 #include "xf86.h"
 #include "xf86Priv.h"
 #include "xf86_OSlib.h"
-#include "lnx.h"
 
 #include <sys/stat.h>
 
@@ -230,9 +229,6 @@ xf86OpenConsole(void)
         {
             struct termios nTty;
 
-#if defined(DO_OS_FONTRESTORE)
-	    lnx_savefont();
-#endif
 	    /*
 	     * now get the VT.  This _must_ succeed, or else fail completely.
 	     */
@@ -296,23 +292,18 @@ xf86OpenConsole(void)
 	    if (ioctl(xf86Info.consoleFd, VT_ACTIVATE, xf86Info.vtno) < 0)
 	        xf86Msg(X_WARNING, "xf86OpenConsole: VT_ACTIVATE failed %s\n",
 		        strerror(errno));
-        }
 
 	    if (ioctl(xf86Info.consoleFd, VT_WAITACTIVE, xf86Info.vtno) < 0)
 	        xf86Msg(X_WARNING, "xf86OpenConsole: VT_WAITACTIVE failed %s\n",
 		        strerror(errno));
+        }
     }
-    return;
 }
 
 void
 xf86CloseConsole(void)
 {
     struct vt_mode   VT;
-#if defined(DO_OS_FONTRESTORE)
-    struct vt_stat vts;
-    int vtno = -1;
-#endif
 
     if (ShareVTs) {
         close(xf86Info.consoleFd);
@@ -324,14 +315,6 @@ xf86CloseConsole(void)
 	console_handler = NULL;
     };
 
-#if defined(DO_OS_FONTRESTORE)
-    if (ioctl(xf86Info.consoleFd, VT_GETSTATE, &vts) < 0)
-	xf86Msg(X_WARNING, "xf86CloseConsole: VT_GETSTATE failed: %s\n",
-		strerror(errno));
-    else
-	vtno = vts.v_active;
-#endif
-
     /* Back to text mode ... */
     if (ioctl(xf86Info.consoleFd, KDSETMODE, KD_TEXT) < 0)
 	xf86Msg(X_WARNING, "xf86CloseConsole: KDSETMODE failed: %s\n",
@@ -366,18 +349,10 @@ xf86CloseConsole(void)
 			strerror(errno));
 	    activeVT = -1;
         }
-
-#if defined(DO_OS_FONTRESTORE)
-        if (xf86Info.vtno == vtno)	/* check if we are active */
-	    lnx_restorefont();
-        lnx_freefontdata();
-#endif
     }
     close(xf86Info.consoleFd);	/* make the vt-manager happy */
 
     restoreVtPerms();		/* restore the permissions */
-
-    return;
 }
 
 int
@@ -421,7 +396,6 @@ xf86UseMsg(void)
 	ErrorF("vtXX                   use the specified VT number\n");
 	ErrorF("-keeptty               ");
 	ErrorF("don't detach controlling tty (for debugging only)\n");
-        ErrorF("-novtswitch            don't immediately switch to new VT\n");
-        ErrorF("-sharevts              share VTs with another X server\n");
-	return;
+	ErrorF("-novtswitch            don't immediately switch to new VT\n");
+	ErrorF("-sharevts              share VTs with another X server\n");
 }
