@@ -579,16 +579,16 @@ void
 LogPrintMarkers(void)
 {
     /* Show what the message marker symbols mean. */
-    ErrorF("Markers: ");
-    LogMessageVerb(X_PROBED, -1, "probed, ");
-    LogMessageVerb(X_CONFIG, -1, "from config file, ");
-    LogMessageVerb(X_DEFAULT, -1, "default setting,\n\t");
-    LogMessageVerb(X_CMDLINE, -1, "from command line, ");
-    LogMessageVerb(X_NOTICE, -1, "notice, ");
-    LogMessageVerb(X_INFO, -1, "informational,\n\t");
-    LogMessageVerb(X_WARNING, -1, "warning, ");
-    LogMessageVerb(X_ERROR, -1, "error, ");
-    LogMessageVerb(X_NOT_IMPLEMENTED, -1, "not implemented, ");
-    LogMessageVerb(X_UNKNOWN, -1, "unknown.\n");
+    LogWrite(0, "Markers: ");
+    LogMessageVerb(X_PROBED, 0, "probed, ");
+    LogMessageVerb(X_CONFIG, 0, "from config file, ");
+    LogMessageVerb(X_DEFAULT, 0, "default setting,\n\t");
+    LogMessageVerb(X_CMDLINE, 0, "from command line, ");
+    LogMessageVerb(X_NOTICE, 0, "notice, ");
+    LogMessageVerb(X_INFO, 0, "informational,\n\t");
+    LogMessageVerb(X_WARNING, 0, "warning, ");
+    LogMessageVerb(X_ERROR, 0, "error, ");
+    LogMessageVerb(X_NOT_IMPLEMENTED, 0, "not implemented, ");
+    LogMessageVerb(X_UNKNOWN, 0, "unknown.\n");
 }
 
